@@ -1,5 +1,5 @@
 package App::File::IsSorted;
-$App::File::IsSorted::VERSION = '0.0.1';
+$App::File::IsSorted::VERSION = '0.0.2';
 use strict;
 use warnings;
 use 5.016;
@@ -15,10 +15,16 @@ __END__
 
 =head1 VERSION
 
-version 0.0.1
+version 0.0.2
 
 =head1 SYNOPSIS
 
+    is-sorted check .gitignore
+
+=head1 DESCRIPTION
+
+Check if the lines of files are sorted.
+
 =head1 NAME
 
 App::File::IsSorted - see L<is-sorted>
